/*
 `DigitNumericFormInput` is a customizable formfield widget that extends the baseforminput.

 Example usage:
 ```dart
 DigitNumericFormInput(
 controller: _textController,
 label: 'Username',
 innerLabel: 'Enter a numeric value',
 charCount: true,
 helpText: 'This is a simple example of DigitNumericFormInput',
 validations: [
 // Example validation: Required field
 Validator(ValidatorType.required),
 ],
 onChange: (value) {
 print(value);
 },
 ),
 ....*/

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import '../../utils/validators/validator.dart';
import 'digit_base_form_input.dart';

class DigitNumericFormInput extends BaseDigitFormInput {
  const DigitNumericFormInput({
    Key? key,
    required TextEditingController controller,
    String? label,
    String? infoText,
    bool? info,
    String? initialValue,
    bool readOnly = false,
    bool isDisabled = false,
    bool isRequired = false,
    bool charCount = false,
    bool editable = false,
    String? innerLabel,
    String? helpText,
    TooltipTriggerMode triggerMode = TooltipTriggerMode.tap,
    bool preferToolTipBelow = false,
    String suffixText = '+',
    String prefixText = '-',
    IconData prefixIcon = Icons.remove,
    void Function(String?)? onError,
    TextInputType keyboardType = TextInputType.number,
    TextAlign textAlign = TextAlign.center,
    final List<Validator>? validations,
    final void Function(String)? onChange,
    final int step = 5,
    final int minValue = 0,
    final int maxValue = 100,
    final List<TextInputFormatter>? inputFormatters,
    final String? errorMessage,
  }) : super(
          key: key,
          controller: controller,
          label: label,
          info: info,
          infoText: infoText,
          readOnly: readOnly,
          isDisabled: isDisabled,
          isRequired: isRequired,
          charCount: charCount,
          innerLabel: innerLabel,
          helpText: helpText,
          triggerMode: triggerMode,
          preferToolTipBelow: preferToolTipBelow,
          suffixText: suffixText,
          prefixText: prefixText,
          onError: onError,
          keyboardType: keyboardType,
          textAlign: textAlign,
          initialValue: initialValue,
          validations: validations,
          onChange: onChange,
          step: step,
          maxValue: maxValue,
          minValue: minValue,
          showCurser: editable,
          isEditable: editable,
          errorMessage: errorMessage,
          inputFormatters: inputFormatters,
        );

  @override
  _DigitNumericFormInputState createState() => _DigitNumericFormInputState();
}

class _DigitNumericFormInputState extends BaseDigitFormInputState {
  @override
  void onPrefixIconClick({void Function()? customFunction}) {
    setState(() {
      /// Subtract step from the input value when the prefix icon is clicked
      int currentValue = int.tryParse(widget.controller.text) ?? 0;
      if ((currentValue - widget.step) >= widget.minValue) {
        setState(() {
          widget.controller.text = (currentValue - widget.step).toString();
        });
/// Remove the text selection
        widget.controller.selection = const TextSelection.collapsed(offset: 0);
      }
    });
  }

  @override
  void onSuffixIconClick({void Function()? customFunction}) {
    setState(() {
      /// Add step to the input value when the suffix icon is clicked
      int currentValue = int.tryParse(widget.controller.text) ?? 0;
      if ((currentValue + widget.step) <= widget.maxValue) {
        setState(() {
          widget.controller.text = (currentValue + widget.step).toString();
        });
/// Remove the text selection
        widget.controller.selection = const TextSelection.collapsed(offset: 0);

      }
    });
  }

  @override
  Widget build(BuildContext context) {
    /// You can customize the appearance or behavior specific to the TextFormInput here
    return super.build(context);
  }
}
